@@ -63,12 +63,24 @@ describe "Simple" do
     }
   end
 
+  it "detects UTF_16BE without BOM" do
+    assert_chardet_spec_detect 'UTF-16BE_without_BOM', {
+      "encoding" => 'UTF-16BE', "confidence" => 0.85
+    }
+  end
+
   it "detects UTF_16LE" do
     assert_chardet_spec_detect 'UTF-16LE', {
       "encoding" => 'UTF-16LE', "confidence" => 1
     }
   end
 
+  it "detects UTF_16LE without BOM" do
+    assert_chardet_spec_detect 'UTF-16LE_without_BOM', {
+      "encoding" => 'UTF-16LE', "confidence" => 0.85
+    }
+  end
+
   it "detects ISO_2022_JP" do
     assert_chardet_spec_detect 'ISO-2022-JP', {
       "encoding" => 'ISO-2022-JP', "confidence" => 0.99
